@@ -76,6 +76,7 @@ class Article(BaseObject):
         self.issue = None
         self.review_articles = []
         self.clinical_trials = []
+        self.preprint = None
 
     def add_contributor(self, contributor):
         self.contributors.append(contributor)
@@ -416,6 +417,12 @@ class ClinicalTrial(BaseObject):
         return None
 
 
+class Preprint(BaseObject):
+    def __init__(self, uri=None, doi=None):
+        self.uri = uri
+        self.doi = doi
+
+
 class ContentBlock:
     def __init__(self, block_type=None, content=None, attr=None):
         self.block_type = block_type
